==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/outputs/AzureMySqlSectionResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property authorityUrl The authority URL used for authentication.
 * @property certificate The content of the certificate used for authentication.
 * @property clientId The Client ID/Application ID
 * @property clientSecret The client secret.
 * @property credentialType Sql Authentication type.
 * @property databaseName The Azure SQL database name.
 * @property endpoint The server host endpoint.
 * @property isCertAuth  Is it using certificate to authenticate. If false then use client secret.
 * @property portNumber / The Azure SQL port number.
 * @property resourceGroup Resource Group.
 * @property resourceUri The resource the service principal/app has access to.
 * @property serverName The Azure SQL server name.
 * @property serviceDataAccessAuthIdentity Indicates which identity to use to authenticate service data access to customer's storage.
 * @property subscriptionId Subscription ID.
 * @property tenantId The ID of the tenant the service principal/app belongs to.
 * @property thumbprint The thumbprint of the certificate above.
 * @property userId The Azure SQL user id.
 * @property userPassword The Azure SQL user password.
 */
public data class AzureMySqlSectionResponse(
    public val authorityUrl: String? = null,
    public val certificate: String? = null,
    public val clientId: String? = null,
    public val clientSecret: String? = null,
    public val credentialType: String? = null,
    public val databaseName: String? = null,
    public val endpoint: String? = null,
    public val isCertAuth: Boolean? = null,
    public val portNumber: String? = null,
    public val resourceGroup: String? = null,
    public val resourceUri: String? = null,
    public val serverName: String? = null,
    public val serviceDataAccessAuthIdentity: String? = null,
    public val subscriptionId: String? = null,
    public val tenantId: String? = null,
    public val thumbprint: String? = null,
    public val userId: String? = null,
    public val userPassword: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.machinelearningservices.outputs.AzureMySqlSectionResponse):
            AzureMySqlSectionResponse = AzureMySqlSectionResponse(
            authorityUrl = javaType.authorityUrl().map({ args0 -> args0 }).orElse(null),
            certificate = javaType.certificate().map({ args0 -> args0 }).orElse(null),
            clientId = javaType.clientId().map({ args0 -> args0 }).orElse(null),
            clientSecret = javaType.clientSecret().map({ args0 -> args0 }).orElse(null),
            credentialType = javaType.credentialType().map({ args0 -> args0 }).orElse(null),
            databaseName = javaType.databaseName().map({ args0 -> args0 }).orElse(null),
            endpoint = javaType.endpoint().map({ args0 -> args0 }).orElse(null),
            isCertAuth = javaType.isCertAuth().map({ args0 -> args0 }).orElse(null),
            portNumber = javaType.portNumber().map({ args0 -> args0 }).orElse(null),
            resourceGroup = javaType.resourceGroup().map({ args0 -> args0 }).orElse(null),
            resourceUri = javaType.resourceUri().map({ args0 -> args0 }).orElse(null),
            serverName = javaType.serverName().map({ args0 -> args0 }).orElse(null),
            serviceDataAccessAuthIdentity = javaType.serviceDataAccessAuthIdentity().map({ args0 ->
                args0
            }).orElse(null),
            subscriptionId = javaType.subscriptionId().map({ args0 -> args0 }).orElse(null),
            tenantId = javaType.tenantId().map({ args0 -> args0 }).orElse(null),
            thumbprint = javaType.thumbprint().map({ args0 -> args0 }).orElse(null),
            userId = javaType.userId().map({ args0 -> args0 }).orElse(null),
            userPassword = javaType.userPassword().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/outputs/AzureMySqlSectionResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property authorityUrl The authority URL used for authentication.
 * @property certificate The content of the certificate used for authentication.
 * @property clientId The Client ID/Application ID
 * @property clientSecret The client secret.
 * @property credentialType Sql Authentication type.
 * @property databaseName The Azure SQL database name.
 * @property endpoint The server host endpoint.
 * @property isCertAuth  Is it using certificate to authenticate. If false then use client secret.
 * @property portNumber / The Azure SQL port number.
 * @property resourceGroup Resource Group.
 * @property resourceUri The resource the service principal/app has access to.
 * @property serverName The Azure SQL server name.
 * @property serviceDataAccessAuthIdentity Indicates which identity to use to authenticate service data access to customer's storage.
 * @property subscriptionId Subscription ID.
 * @property tenantId The ID of the tenant the service principal/app belongs to.
 * @property thumbprint The thumbprint of the certificate above.
 * @property userId The Azure SQL user id.
 * @property userPassword The Azure SQL user password.
 */
public data class AzureMySqlSectionResponse(
    public val authorityUrl: String? = null,
    public val certificate: String? = null,
    public val clientId: String? = null,
    public val clientSecret: String? = null,
    public val credentialType: String? = null,
    public val databaseName: String? = null,
    public val endpoint: String? = null,
    public val isCertAuth: Boolean? = null,
    public val portNumber: String? = null,
    public val resourceGroup: String? = null,
    public val resourceUri: String? = null,
    public val serverName: String? = null,
    public val serviceDataAccessAuthIdentity: String? = null,
    public val subscriptionId: String? = null,
    public val tenantId: String? = null,
    public val thumbprint: String? = null,
    public val userId: String? = null,
    public val userPassword: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.machinelearningservices.outputs.AzureMySqlSectionResponse): AzureMySqlSectionResponse = AzureMySqlSectionResponse(
            authorityUrl = javaType.authorityUrl().map({ args0 -> args0 }).orElse(null),
            certificate = javaType.certificate().map({ args0 -> args0 }).orElse(null),
            clientId = javaType.clientId().map({ args0 -> args0 }).orElse(null),
            clientSecret = javaType.clientSecret().map({ args0 -> args0 }).orElse(null),
            credentialType = javaType.credentialType().map({ args0 -> args0 }).orElse(null),
            databaseName = javaType.databaseName().map({ args0 -> args0 }).orElse(null),
            endpoint = javaType.endpoint().map({ args0 -> args0 }).orElse(null),
            isCertAuth = javaType.isCertAuth().map({ args0 -> args0 }).orElse(null),
            portNumber = javaType.portNumber().map({ args0 -> args0 }).orElse(null),
            resourceGroup = javaType.resourceGroup().map({ args0 -> args0 }).orElse(null),
            resourceUri = javaType.resourceUri().map({ args0 -> args0 }).orElse(null),
            serverName = javaType.serverName().map({ args0 -> args0 }).orElse(null),
            serviceDataAccessAuthIdentity = javaType.serviceDataAccessAuthIdentity().map({ args0 ->
                args0
            }).orElse(null),
            subscriptionId = javaType.subscriptionId().map({ args0 -> args0 }).orElse(null),
            tenantId = javaType.tenantId().map({ args0 -> args0 }).orElse(null),
            thumbprint = javaType.thumbprint().map({ args0 -> args0 }).orElse(null),
            userId = javaType.userId().map({ args0 -> args0 }).orElse(null),
            userPassword = javaType.userPassword().map({ args0 -> args0 }).orElse(null),
        )
    }
}
